package WWW::Shorten::NotLong;

use 5.006;
use strict;
use warnings;

our $VERSION = '9.992';
$VERSION = eval $VERSION;

require WWW::Shorten::_dead;

0;

=head1 NAME

WWW::Shorten::NotLong - (DEPRECATED) Shorten URLs

=head1 SYNOPSIS

  # no viable use case

=head1 DESCRIPTION

This module is deprecated since the service no longer functions.  Please
see L<WWW::Shorten> instead.

=head1 AUTHOR

Eric Hammond C<ehammond@thinksome.com>

=head1 CONTRIBUTORS

=over

=item *

Chase Whitener C<capoeirab@cpan.org>

=item *

Dave Cross C<dave@perlhacks.com>

=item *

Iain Truskett C<spoon@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

Under the terms and copyright of L<WWW::Shorten>

=head1 SEE ALSO

L<WWW::Shorten>

=cut
